@@ -8,9 +8,12 @@
 
 #include "src/mfx_dispatcher_vpl.h"
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     #include "src/mfx_dispatcher_vpl_win.h"
 #endif
+#ifdef __CYGWIN__
+#define wcstombs_s(a,b,c,d,e) wcstombs(b,d,c)
+#endif
 
 // leave table formatting alone
 // clang-format off
@@ -123,7 +126,7 @@ mfxU32 LoaderCtxVPL::ParseEnvSearchPaths(const CHAR_TYPE *envVarName,
                                          std::list<STRING_TYPE> &searchDirs) {
     searchDirs.clear();
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     DWORD err;
     m_envVar[0] = 0;
 
@@ -163,7 +166,7 @@ mfxStatus LoaderCtxVPL::SearchDirForLibs(STRING_TYPE searchDir,
     if (searchDir.empty())
         return MFX_ERR_NONE;
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     HANDLE hTestFile = nullptr;
     WIN32_FIND_DATAW testFileData;
     DWORD err;
@@ -310,7 +313,7 @@ mfxU32 LoaderCtxVPL::GetSearchPathsDriverStore(std::list<STRING_TYPE> &searchDir
                                                LibType libType) {
     searchDirs.clear();
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     mfxStatus sts = MFX_ERR_UNSUPPORTED;
     STRING_TYPE vplPath;
 
@@ -336,7 +339,7 @@ mfxU32 LoaderCtxVPL::GetSearchPathsDriverStore(std::list<STRING_TYPE> &searchDir
 mfxU32 LoaderCtxVPL::GetSearchPathsCurrentExe(std::list<STRING_TYPE> &searchDirs) {
     searchDirs.clear();
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     // get path to location of current executable
     wchar_t implPath[MFX::msdk_disp_path_len];
     bool ret            = MFX::GetImplPath(MFX::MFX_APP_FOLDER, implPath);
@@ -366,7 +369,7 @@ mfxU32 LoaderCtxVPL::GetSearchPathsCurrentExe(std::list<STRING_TYPE> &searchDirs
 mfxU32 LoaderCtxVPL::GetSearchPathsCurrentDir(std::list<STRING_TYPE> &searchDirs) {
     searchDirs.clear();
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     CHAR_TYPE currDir[MAX_VPL_SEARCH_PATH] = L"";
     if (GetCurrentDirectoryW(MAX_VPL_SEARCH_PATH, currDir)) {
         searchDirs.push_back(currDir);
@@ -387,7 +390,7 @@ mfxU32 LoaderCtxVPL::GetSearchPathsCurrentDir(std::list<STRING_TYPE> &searchDirs
 mfxU32 LoaderCtxVPL::GetSearchPathsLegacy(std::list<STRING_TYPE> &searchDirs) {
     searchDirs.clear();
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     mfxStatus sts = MFX_ERR_UNSUPPORTED;
     STRING_TYPE msdkPath;
 
@@ -432,7 +435,7 @@ mfxU32 LoaderCtxVPL::GetSearchPathsLegacy(std::list<STRING_TYPE> &searchDirs) {
 mfxU32 LoaderCtxVPL::GetSearchPathsSystemDefault(std::list<STRING_TYPE> &searchDirs) {
     searchDirs.clear();
 
-#if defined(__linux__) || defined(__CYGWIN__)
+#ifdef __linux__
     // Add the standard path for libmfx1 install in Ubuntu
     searchDirs.push_back("/usr/lib/x86_64-linux-gnu");
 
@@ -484,7 +487,7 @@ mfxStatus LoaderCtxVPL::BuildListOfCandidateLibs() {
     if (searchDirList.size() > 0)
         m_bPriorityPathEnabled = true;
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     // retrieve list of DX11 graphics adapters (lightweight)
     // used for both Intel® VPL and legacy driver store search
     m_gpuAdapterInfo.clear();
@@ -673,7 +676,7 @@ mfxU32 LoaderCtxVPL::CheckValidLibraries() {
                     }
                 }
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
                 // workaround for double-init issue in old versions of MSDK runtime
                 //   (allow DLL to be fully unloaded after each call to MFXClose)
                 // apply to MSDK with API version <= 1.27
@@ -720,7 +723,7 @@ VPLFunctionPtr LoaderCtxVPL::GetFunctionAddr(void *hModuleVPL, const char *pName
     VPLFunctionPtr pProc = nullptr;
 
     if (hModuleVPL) {
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
         pProc = (VPLFunctionPtr)MFX::mfx_dll_get_addr(hModuleVPL, pName);
 #else
         pProc = (VPLFunctionPtr)dlsym(hModuleVPL, pName);
@@ -735,7 +738,7 @@ mfxStatus LoaderCtxVPL::LoadSingleLibrary(LibInfo *libInfo) {
     if (!libInfo)
         return MFX_ERR_NULL_PTR;
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     libInfo->hModuleVPL = MFX::mfx_dll_load(libInfo->libNameFull.c_str());
 #else
     libInfo->hModuleVPL = dlopen(libInfo->libNameFull.c_str(), RTLD_LOCAL | RTLD_NOW);
@@ -751,7 +754,7 @@ mfxStatus LoaderCtxVPL::LoadSingleLibrary(LibInfo *libInfo) {
 mfxStatus LoaderCtxVPL::UnloadSingleLibrary(LibInfo *libInfo) {
     if (libInfo) {
         if (libInfo->hModuleVPL) {
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
             MFX::mfx_dll_free(libInfo->hModuleVPL);
 #else
             dlclose(libInfo->hModuleVPL);
@@ -897,7 +900,7 @@ mfxStatus LoaderCtxVPL::ValidateAPIExports(VPLFunctionPtr *vplFuncTable,
 
 // convert full path into char* for MFX_IMPLCAPS_IMPLPATH query
 mfxStatus LoaderCtxVPL::UpdateImplPath(LibInfo *libInfo) {
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     // Windows - strings are 16-bit
     size_t nCvt = 0;
     if (wcstombs_s(&nCvt,
@@ -1798,7 +1801,7 @@ mfxStatus LoaderCtxVPL::FreeConfigFilters() {
 mfxStatus LoaderCtxVPL::InitDispatcherLog() {
     std::string strLogEnabled, strLogFile;
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     DWORD err;
 
     char logEnabled[MAX_VPL_SEARCH_PATH] = "";
